/* Propri<E9>t<E9>s communes */
body {
        color: #888;
        background-color: #fff;
        font-family: verdana, sans-serif;
        font-size: 12px;
        text-align: center;
}
a {
        color: #888; 
        text-decoration: none;
        font-weight: bold;
}
a:hover {
        color: #888;
        text-decoration: underline;
}

/* Titre haut de page */
.titre {
        margin: 30px 10px 2px 10px;
        font-weight: bold;
        font-size: 200%;
        color: #fe8622;
}
.barre {
        border-top: 1px dashed #ccc;
        width: 400px;
        margin: auto;
        margin-bottom: 20px;
}

/* Corps de la page */
table {
        width: 350px;
        margin: auto;
        text-align: left;
        font-family: verdana, sans-serif;
        font-size: 12px;
}
input {
        width: 250px;
        margin-left: 20px;
}
textarea {
        margin-left: 20px;
        width: 250px;
}


