<html>
 
<head>
 
<!-- Le titre de la page -->
<title>.:: Formulaire d'envoi de mails ::.</title>
 
<!-- Feuille de style, pour le côté graphique -->
<link rel="stylesheet" type="text/css" href="nfrance.css">
</head>
 
<body>
 
<!-- Titre de la page -->
<div class="titre">.:: Formulaire d'envoi de mails ::.</div>
<div class="barre">&nbsp;</div>
 
<!-- Déclaration du formulaire -->
<form method="post" action="envoi.php">
 
<table>
   <tr>
      <td>De : </td>
      <td><input type="text" name="de" value="Votre adresse email"></td>
   </tr>
   <tr>
      <td>A : </td>
      <td><input type="text" name="a" value="L'adresse email de votre contact"></td>
   </tr>
   <tr>
      <td>Sujet : </td>
      <td><input type="text" name="sujet" value="Sujet de votre mail"></td>
   </tr>
   <tr>
      <td>Message : </td>
      <td><textarea name="message" rows=5>Votre message</textarea></td>
   </tr>
   <tr>
      <td></td>
      <td><input type="submit" value="Envoyer"></td>
   </tr>
</table>
 
</form>
 
</body>
</html>
